package cn.com.ctop.job.kuaishou.handler;

import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.service.ICtopOauthTokenService;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.kuaishou.modules.ai.entity.KuaishouPopulationPackageRel;
import cn.com.ctop.kuaishou.modules.ai.mapper.KuaishouPopulationPackageMapper;
import cn.com.ctop.kuaishou.modules.ai.mapper.KuaishouPopulationPackageRelMapper;
import cn.com.ctop.kuaishou.modules.ai.service.IKuaishouPopulationPackageRelService;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaishouPopulationService;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import org.jeecg.common.util.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

@Component
public class CrowdListQueryJob {
    @Autowired
    private ICtopOauthTokenService tokenService;
    @Autowired
    private IKuaishouPopulationService iKuaishouPopulationService;
    @Autowired
    private KuaishouPopulationPackageMapper kuaishouPopulationPackageMapper;
    @Autowired
    private KuaishouPopulationPackageRelMapper relMapper;
    @Autowired
    private IKuaishouPopulationPackageRelService relService;
    static ExecutorService executorService = Executors.newFixedThreadPool(3);

    @XxlJob("crowdListQueryJob")
    public void execute() {
        List<Integer> list = new ArrayList<>();
        for (int i = 0; i <= 7; i++) {
            if (i != 2) {
                list.add(i);
            }
        }
        List<JSONObject> objs = kuaishouPopulationPackageMapper.queryListByStatus();
        list.forEach(status -> executorService.submit(() -> {
            for (JSONObject o : objs) {
                Long accountId = o.getLong("account_id");
                Long projectId = o.getLong("project_id");
                CtopOauthToken token = tokenService.getTokenByAccountId(accountId);
                if (!Check.isNull(token)) {
                    JSONObject jsonObject = iKuaishouPopulationService.getPopulationList(accountId, token.getAccessToken(), status);
                    if (jsonObject.getInteger("code") == 0) {
                        JSONObject data = jsonObject.getJSONObject("data");
                        if (!Check.isNull(data)) {
                            JSONArray details = data.getJSONArray("details");
                            if (details.size() > 0) {
                                for (int j = 0; j < details.size(); j++) {
                                    JSONObject obj = details.getJSONObject(j);
                                    KuaishouPopulationPackageRel rel = JSONObject.parseObject(obj.toJSONString(), KuaishouPopulationPackageRel.class);
                                    if (Check.isNull(relMapper.queryByOrientationId(rel.getOrientationId(), rel.getAccountId()))) {
                                        rel.setProjectId(projectId);
                                        rel.setDataStatus(1);
                                        rel.setStatDate(DateUtils.formatDate(new Date()));
                                        relService.save(rel);
                                    } else {
                                        relMapper.updateStatus(rel);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }));
        XxlJobHelper.log("快手人群报表更新成功");
    }
}
